## 1.8.0.20240520 (2024-05-20)

Add 3.13 to our CI (#11926)

## 1.8.0.20240425 (2024-04-25)

Bump pyright to v1.1.360 (#11810)

## 1.8.0.20240311 (2024-03-11)

Replace Flake8 checks with Ruff (except for flake8-pyi) (#11496)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

Use PEP 570 syntax in third party stubs (#11554)

## 1.8.0.20240301 (2024-03-01)

WebOb: Complete the stubs and activate stricter pyright config (#11460)

Fix invalid noqa comments and poorly formatted type ignores (#11497)

## 1.8.0.20240128 (2024-01-28)

WebOb: CacheControl descriptors are always allowed to accept `None` (#11288)

## 1.8.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 1.8.0.5 (2023-11-24)

Fix typos in docs and comments (#11064)

Third-party stubs: remove unused `type: ignore`s (#11063)

## 1.8.0.4 (2023-11-11)

third-party: make some protocol params pos-only (#11006)

## 1.8.0.3 (2023-10-27)

Finish stubs for `webob.cookies` and improve `samesite` type (#10927)

## 1.8.0.2 (2023-08-13)

Fill in all missing `upstream_repository` fields (#10571)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.8.0.1 (2023-06-27)

Fixes incorrect return value for `MultiDict.get` without `default` param (#10367)

## 1.8.0.0 (2023-06-18)

Add stubs for WebOb (#9874)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

